@@ -251,7 +251,7 @@ class Form:
         if self.type is None:
             raise s_exc.NoSuchType(name=name)
 
-        self.type.form = self
+        self.form = self
 
         self.props = {}     # name: Prop()
         self.ifaces = {}    # name: <ifacedef>
@@ -506,10 +506,6 @@ class Model:
         item = s_types.Array(self, 'array', info, {'type': 'int'})
         self.addBaseType(item)
 
-        # info = {'doc': 'A list type for storing multiple values of the same type.'}
-        # item = s_types.List(self, 'list', info, {'type': 'str'})
-        # self.addBaseType(item)
-
         info = {'doc': 'An digraph edge base type.'}
         item = s_types.Edge(self, 'edge', info, {})
         self.addBaseType(item)
@@ -531,6 +527,14 @@ class Model:
         item = s_types.HugeNum(self, 'hugenum', info, {})
         self.addBaseType(item)
 
+        info = {'doc': 'A component of a hierarchical taxonomy.'}
+        item = s_types.Taxon(self, 'taxon', info, {})
+        self.addBaseType(item)
+
+        info = {'doc': 'A hierarchical taxonomy.'}
+        item = s_types.Taxonomy(self, 'taxonomy', info, {})
+        self.addBaseType(item)
+
         # add the base universal properties...
         self.addUnivProp('seen', ('ival', {}), {
             'doc': 'The time interval for first/last observation of the node.',
@@ -540,6 +544,17 @@ class Model:
             'doc': 'The time the node was created in the cortex.',
         })
 
+        self.addIface('taxonomy', {
+            'props': (
+                ('title', ('str', {}), {'doc': 'A brief title of the definition.'}),
+                ('summary', ('str', {}), {'doc': 'A summary of the definition.', 'disp': {'hint': 'text'}}),
+                ('sort', ('int', {}), {'doc': 'A display sort order for siblings.', }),
+                ('base', ('taxon', {}), {'ro': True, 'doc': 'The base taxon.', }),
+                ('depth', ('int', {}), {'ro': True, 'doc': 'The depth indexed from 0.', }),
+                ('parent', ('$self', {}), {'ro': True, 'doc': 'The taxonomy parent.', }),
+            ),
+        })
+
     def getPropsByType(self, name):
         props = self.propsbytype.get(name, ())
         # TODO order props based on score...
@@ -574,6 +589,7 @@ class Model:
         retn = {
             'types': {},
             'forms': {},
+            'univs': {},
             'tagprops': {},
             'interfaces': self.ifaces.copy()
         }
@@ -584,6 +600,9 @@ class Model:
         for fobj in self.forms.values():
             retn['forms'][fobj.name] = fobj.pack()
 
+        for uobj in self.univs.values():
+            retn['univs'][uobj.name] = uobj.pack()
+
         for pobj in self.tagprops.values():
             retn['tagprops'][pobj.name] = pobj.pack()
 
@@ -804,6 +823,8 @@ class Model:
             raise s_exc.NoSuchName(mesg=mesg)
 
         for propname, typedef, propinfo in iface.get('props', ()):
+            if typedef[0] == '$self':
+                typedef = (form.name, typedef[1])
             self._addFormProp(form, propname, typedef, propinfo)
 
         # TODO use this to allow storm: +foo:iface
