@@ -1,4 +1,5 @@
 import os
+import asyncio
 import logging
 
 import synapse.exc as s_exc
@@ -70,6 +71,7 @@ class AhaApi(s_cell.CellApi):
                 logger.warning(mesg)
                 return
 
+            logger.debug(f'AhaCellApi fini, tearing down [{name}]')
             coro = self.cell.setAhaSvcDown(name, sess, network=network)
             self.cell.schedCoro(coro)  # this will eventually execute or get cancelled.
 
@@ -122,7 +124,7 @@ class AhaCell(s_cell.Cell):
         dirn = s_common.gendir(self.dirn, 'slabs', 'jsonstor')
 
         slab = await s_lmdbslab.Slab.anit(dirn)
-        self.jsonstor = await s_jsonstor.JsonStor.anit(slab, 'aha')
+        self.jsonstor = await s_jsonstor.JsonStor.anit(slab, 'aha')  # type: s_jsonstor.JsonStor
 
         async def fini():
             await self.jsonstor.fini()
@@ -143,6 +145,7 @@ class AhaCell(s_cell.Cell):
             network = svc.get('svcnetw')
             linkiden = svc.get('svcinfo').get('online')
             if linkiden not in current_sessions:
+                logger.debug(f'AhaCell activecoro tearing down [{svcname}.{network}]')
                 await self.setAhaSvcDown(svcname, linkiden, network=network)
 
         # Wait until we are cancelled or the cell is fini.
@@ -210,14 +213,33 @@ class AhaCell(s_cell.Cell):
         # mostly for testing...
         await self.fire('aha:svcdel', svcname=svcname, svcnetw=svcnetw)
 
-    @s_nexus.Pusher.onPushAuto('aha:svc:down')
     async def setAhaSvcDown(self, name, linkiden, network=None):
         svcname, svcnetw, svcfull = self._nameAndNetwork(name, network)
         path = ('aha', 'services', svcnetw, svcname)
+
+        svcinfo = await self.jsonstor.getPathObjProp(path, 'svcinfo')
+        if svcinfo.get('online') is None:
+            return
+
+        await self._push('aha:svc:down', name, linkiden, network=network)
+
+    @s_nexus.Pusher.onPush('aha:svc:down')
+    async def _setAhaSvcDown(self, name, linkiden, network=None):
+        svcname, svcnetw, svcfull = self._nameAndNetwork(name, network)
+        path = ('aha', 'services', svcnetw, svcname)
         await self.jsonstor.cmpDelPathObjProp(path, 'svcinfo/online', linkiden)
-        logger.debug(f'Set [{svcfull}] offline.')
+
+        # Check if we have any links which may need to be removed
+        current_sessions = {s_common.guid(iden): sess for iden, sess in self.dmon.sessions.items()}
+        sess = current_sessions.get(linkiden)
+        if sess is not None:
+            for link in [lnk for lnk in self.dmon.links if lnk.get('sess') is sess]:
+                await link.fini()
+
         await self.fire('aha:svcdown', svcname=svcname, svcnetw=svcnetw)
 
+        logger.debug(f'Set [{svcfull}] offline.')
+
     async def getAhaSvc(self, name):
         path = ('aha', 'svcfull', name)
         svcinfo = await self.jsonstor.getPathObj(path)
