@@ -241,6 +241,10 @@ class Auth(s_nexus.Pusher):
 
         role = await self.reqRole(iden)
 
+        if role.name == 'all':
+            mesg = 'Role "all" may not be renamed.'
+            raise s_exc.BadArg(mesg=mesg)
+
         self.rolesbyname.pop(role.name, None)
         self.rolesbyname[name] = role
 
@@ -585,6 +589,7 @@ class AuthGate(s_base.Base):
 
         return {
             'iden': self.iden,
+            'type': self.type,
             'users': users,
             'roles': roles,
         }
@@ -739,6 +744,7 @@ class HiveUser(HiveRuler):
         return await self.auth.setUserName(self.iden, name)
 
     def allowed(self, perm, default=None, gateiden=None):
+        perm = tuple(perm)
         return self.permcache.get((perm, default, gateiden))
 
     def _allowed(self, pkey):
