@@ -1,3 +1,5 @@
+import os
+import shutil
 import asyncio
 import logging
 import functools
@@ -16,8 +18,6 @@ logger = logging.getLogger(__name__)
 # As a mirror follower, amount of time before giving up on a write request
 FOLLOWER_WRITE_WAIT_S = 30.0
 
-NexusLogEntryT = Tuple[str, str, List[Any], Dict[str, Any], Dict] # (nexsiden, event, args, kwargs, meta)
-
 class RegMethType(type):
     '''
     Metaclass that collects all methods in class with _regme prop into a class member called _regclstupls
@@ -53,7 +53,7 @@ class ChangeDist(s_base.Base):
 
         while not self.isfini:
 
-            for item in self.nexuslog.iter(self.offs):
+            async for item in self.nexuslog.iter(self.offs):
                 self.offs = item[0] + 1
                 yield item
 
@@ -72,11 +72,13 @@ class ChangeDist(s_base.Base):
 
 class NexsRoot(s_base.Base):
 
-    async def __anit__(self, dirn: str, donexslog: bool = True, map_async=False):  # type: ignore
+    async def __anit__(self, dirn: str, donexslog: bool = True, map_async=False):
 
         await s_base.Base.__anit__(self)
 
-        import synapse.lib.lmdbslab as s_lmdbslab  # avoid import cycle
+        # avoid import cycle
+        import synapse.lib.lmdbslab as s_lmdbslab
+        import synapse.lib.multislabseqn as s_multislabseqn
 
         self.dirn = dirn
         self.client = None
@@ -92,20 +94,34 @@ class NexsRoot(s_base.Base):
         self._futures: Dict[str, asyncio.Future] = {}
 
         path = s_common.genpath(self.dirn, 'slabs', 'nexus.lmdb')
+        fresh = not os.path.exists(path)
+
+        logpath = s_common.genpath(self.dirn, 'slabs', 'nexuslog')
 
         self.map_async = map_async
         self.nexsslab = await s_lmdbslab.Slab.anit(path, map_async=map_async)
-
-        self.nexslog = self.nexsslab.getSeqn('nexuslog')
         self.nexshot = await self.nexsslab.getHotCount('nexs:indx')
 
+        if fresh:
+            self.nexshot.set('version', 2)
+
+        vers = self.nexshot.get('version')
+
+        if vers <= 1:
+            await self._migrateV1toV2(path, logpath)
+        elif vers != 2:
+            raise s_exc.BadStorageVersion(mesg=f'Got nexus log version {vers}.  Expected 2.  Accidental downgrade?')
+
+        slabopts = {'map_async': map_async}
+        self.nexslog = await s_multislabseqn.MultiSlabSeqn.anit(logpath, slabopts=slabopts)
+
         # just in case were previously configured differently
         logindx = self.nexslog.index()
         hotindx = self.nexshot.get('nexs:indx')
         maxindx = max(logindx, hotindx)
 
         self.nexshot.set('nexs:indx', maxindx)
-        self.nexslog.indx = maxindx
+        self.nexslog.setIndex(maxindx)
 
         async def fini():
 
@@ -113,9 +129,74 @@ class NexsRoot(s_base.Base):
                 futu.cancel()
 
             await self.nexsslab.fini()
+            await self.nexslog.fini()
 
         self.onfini(fini)
 
+    async def _migrateV1toV2(self, nexspath, logpath):
+        '''
+        Close the slab, move it to the new multislab location, then copy out the nexshot
+        values, then drop the nexshot db from the multislab
+        '''
+        logger.warning(f'Migrating Nexus log v1->v2 for {nexspath}')
+
+        if os.path.ismount(nexspath):  # pragma: no cover
+            # Fail fast if the nexspath is its own mountpoint.
+            mesg = f'The nexpath={nexspath} is located at its own mount point. This configuration cannot be migrated.'
+            raise s_exc.BadCoreStore(mesg=mesg, nexspath=nexspath)
+
+        # avoid import cycle
+        import synapse.lib.lmdbslab as s_lmdbslab
+        import synapse.lib.multislabseqn as s_multislabseqn
+
+        # Grab the initial index value
+        seqn = self.nexsslab.getSeqn('nexuslog')
+        first = seqn.first()
+        if first is None:
+            # Nothing in the sequence.  Drop and move along.
+            self.nexsslab.dropdb('nexuslog')
+            self.nexshot.set('version', 2)
+            logger.warning('Nothing in the nexuslog sequence to migrate.')
+            logger.warning('...Nexus log migration complete')
+            return
+
+        await self.nexsslab.fini()
+
+        firstidx = first[0]
+
+        fn = s_multislabseqn.MultiSlabSeqn.slabFilename(logpath, firstidx)
+        logger.warning(f'Existing nexslog will be migrated from {nexspath} to {fn}')
+
+        if os.path.exists(fn):  # pragma: no cover
+            logger.warning(f'Removing old migration which may have failed. This should not exist: {fn}')
+            shutil.rmtree(fn)
+
+        os.makedirs(fn, exist_ok=True)
+        logger.warning(f'Moving existing nexslog')
+        try:
+            os.replace(nexspath, fn)
+        except OSError as e:  # pragma: no cover
+            logger.exception('Error during nexslog migration.')
+            raise s_exc.BadCoreStore(mesg='Error during nexslogV1toV2', nexspath=nexspath, fn=fn) from e
+
+        # Open a fresh slab where the old one used to be
+        logger.warning(f'Re-opening fresh nexslog slab at {nexspath} for nexshot')
+        self.nexsslab = await s_lmdbslab.Slab.anit(nexspath, map_async=self.map_async)
+        self.nexshot = await self.nexsslab.getHotCount('nexs:indx')
+
+        logger.warning('Copying nexs:indx data from migrated slab to the fresh nexslog')
+        # There's only one value in nexs:indx, so this should be fast
+        async with await s_lmdbslab.Slab.anit(fn) as newslab:
+            olddb = self.nexsslab.initdb('nexs:indx')
+            self.nexsslab.dropdb(olddb)
+            db = newslab.initdb('nexs:indx')
+            newslab.copydb('nexs:indx', self.nexsslab, destdbname='nexs:indx')
+            newslab.dropdb(db)
+
+        self.nexshot.set('version', 2)
+
+        logger.warning('...Nexus log migration complete')
+
     @contextlib.contextmanager
     def _getResponseFuture(self, iden=None):
 
@@ -145,7 +226,7 @@ class NexsRoot(s_base.Base):
         if not self.donexslog: # pragma: no cover
             return
 
-        indxitem = self.nexslog.last()
+        indxitem = await self.nexslog.last()
         if indxitem is None:
             # We have a brand new log
             return
@@ -207,6 +288,15 @@ class NexsRoot(s_base.Base):
         else:
             return self.nexshot.get('nexs:indx')
 
+    async def cull(self, offs):
+        return await self.nexslog.cull(offs)
+
+    async def rotate(self):
+        return await self.nexslog.rotate()
+
+    async def waitOffs(self, offs, timeout=None):
+        return await self.nexslog.waitForOffset(offs, timeout)
+
     async def setindex(self, indx):
 
         nexsindx = await self.index()
@@ -215,7 +305,7 @@ class NexsRoot(s_base.Base):
             return False
 
         if self.donexslog:
-            self.nexslog.indx = indx
+            self.nexslog.setIndex(indx)
         else:
             self.nexshot.set('nexs:indx', indx)
 
@@ -224,7 +314,7 @@ class NexsRoot(s_base.Base):
     async def _eat(self, item, indx=None):
 
         if self.donexslog:
-            saveindx = self.nexslog.add(item, indx=indx)
+            saveindx = await self.nexslog.add(item, indx=indx)
             [dist.update() for dist in tuple(self._mirrors)]
 
         else:
@@ -261,7 +351,7 @@ class NexsRoot(s_base.Base):
 
         maxoffs = offs
 
-        for item in self.nexslog.iter(offs):
+        async for item in self.nexslog.iter(offs):
             if self.isfini: # pragma: no cover
                 raise s_exc.IsFini()
             maxoffs = item[0] + 1
