@@ -237,12 +237,6 @@ class CmdCoreTest(s_t_utils.SynTest):
             await realcore.nodes('[ inet:ipv4=1.2.3.4 +#visi.woot ]')
             await s_lmdbslab.Slab.syncLoopOnce()
 
-            # The storm --spawn option works
-            outp = self.getTestOutp()
-            cmdr = await s_cmdr.getItemCmdr(core, outp=outp)
-            await cmdr.runCmdLine('storm --spawn inet:ipv4=1.2.3.4')
-            outp.expect('#visi.woot')
-
     async def test_log(self):
 
         def check_locs_cleanup(cobj):
