@@ -34,6 +34,8 @@ class EconTest(s_utils.SynTest):
 
                     :paid=true
                     :paid:time=20180202
+
+                    :settled=20180205
             ]'''
 
             perc = (await core.nodes(text))[0]
@@ -90,6 +92,8 @@ class EconTest(s_utils.SynTest):
             self.eq(True, perc.get('paid'))
             self.eq(1517529600000, perc.get('paid:time'))
 
+            self.eq(1517788800000, perc.get('settled'))
+
             self.eq(1517529600000, perc.get('time'))
             self.eq(place, perc.get('place'))
 
@@ -100,6 +104,7 @@ class EconTest(s_utils.SynTest):
             self.eq(perc.ndef[1], acqu.get('purchase'))
 
             self.len(1, await core.nodes('econ:acquired:item:form=inet:fqdn'))
+            self.len(1, await core.nodes('inet:fqdn=vertex.link'))
 
             self.eq(('inet:fqdn', 'vertex.link'), acqu.get('item'))
 
@@ -187,3 +192,13 @@ class EconTest(s_utils.SynTest):
             self.eq('9999.01', nodes[0].get('price:close'))
             self.eq('999999999999.00', nodes[0].get('price:high'))
             self.eq('0.00001', nodes[0].get('price:low'))
+
+            nodes = await core.nodes('[ econ:acct:payment=* :from:contract=* :to:contract=* :memo="2012 Chateauneuf du Pape" ]')
+            self.len(1, nodes)
+            self.eq('2012 Chateauneuf du Pape', nodes[0].get('memo'))
+            self.nn(nodes[0].get('to:contract'))
+            self.nn(nodes[0].get('from:contract'))
+            nodes = await core.nodes('econ:acct:payment :to:contract -> ou:contract')
+            self.len(1, nodes)
+            nodes = await core.nodes('econ:acct:payment :from:contract -> ou:contract')
+            self.len(1, nodes)
