@@ -1,16 +1,10 @@
-# -*- coding: utf-8 -*-
-"""
-synapse - test_utils.py.py
-Created on 10/21/17.
-
-Test for synapse.tests.utils classes
-"""
 import os
 import time
 import logging
 
 import synapse.common as s_common
 
+import synapse.lib.base as s_base
 import synapse.lib.output as s_output
 
 import synapse.tests.utils as s_t_utils
@@ -144,12 +138,14 @@ class TestUtils(s_t_utils.SynTest):
         outp.expect('#1')
         self.raises(Exception, outp.expect, 'oh my')
 
-    def test_testenv(self):
+    async def test_testenv(self):
 
-        with s_t_utils.TstEnv() as env:
+        async with s_t_utils.TstEnv() as env:
 
+            base = await s_base.Base.anit()
             foo = 'foo'
             env.add('foo', foo)
+            env.add('base', base, fini=True)
 
             self.true(env.foo is foo)
 
@@ -158,6 +154,8 @@ class TestUtils(s_t_utils.SynTest):
 
             self.raises(AttributeError, blah)
 
+        self.true(base.isfini)
+
     async def test_cmdg_simple_sequence(self):
         cmdg = s_t_utils.CmdGenerator(['foo', 'bar'])
         self.eq(await cmdg(), 'foo')
@@ -198,11 +196,30 @@ class TestUtils(s_t_utils.SynTest):
     async def test_storm_mesgs(self):
 
         async with self.getTestCore() as core:
-            mesgs = await core.streamstorm('[test:str=1234] | count').list()
+
+            mesgs = await core.stormlist('[test:str=1234] | count')
             self.stormIsInPrint('Counted 1 nodes.', mesgs)
 
-            mesgs = await core.streamstorm('iden newp').list()
+            mesgs = await core.stormlist('iden newp')
             self.stormIsInWarn('Failed to decode iden', mesgs)
 
-            mesgs = await core.streamstorm('[test:str=').list()
+            mesgs = await core.stormlist('[test:str=')
             self.stormIsInErr('Unexpected end', mesgs)
+
+    async def test_stable_uids(self):
+        with self.withStableUids():
+            guid = s_common.guid()
+            self.eq('000000', guid[:6])
+            guid2 = s_common.guid()
+            self.ne(guid, guid2)
+
+            guid = s_common.guid(42)
+            self.ne('000000', guid[:6])
+
+            buid = s_common.buid()
+            self.eq(b'\00\00\00\00\00\00', buid[:6])
+            buid2 = s_common.buid()
+            self.ne(buid, buid2)
+
+            buid = s_common.buid(42)
+            self.ne(b'\00\00\00\00\00\00', buid[:6])
